/*
 * Copyright (C) 2019  Haowei Wen <yushijinhun@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package moe.yushi.authlibinjector.internal.fi.iki.elonen;

import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;

/**
 * @author yushijinhun
 */
class FixedLengthInputStream extends InputStream {

	private final InputStream in;
	private long remaining = 0;

	public FixedLengthInputStream(InputStream in, long length) {
		this.remaining = length;
		this.in = in;
	}

	@Override
	public synchronized int read() throws IOException {
		if (remaining > 0) {
			int result = in.read();
			if (result == -1) {
				throw new EOFException();
			}
			remaining--;
			return result;
		} else {
			return -1;
		}
	}

	@Override
	public synchronized int available() throws IOException {
		return Math.min(in.available(), (int) remaining);
	}
}
